#include <bits/stdc++.h>
using namespace std;
 
const long double pi = 3.14159265358979323846264338;
 
struct point {
    long double x, y;
};
 
point operator+(const point &a, const point &b) {
    return {a.x + b.x, a.y + b.y};
}
 
point operator-(const point &a, const point &b) {
    return {a.x - b.x, a.y - b.y};
}
 
long double dp(const point &a, const point &b) {
    return a.x * b.x + a.y * b.y;
}
 
long double cp(const point &a, const point &b) {
    return a.x * b.y - a.y * b.x;
}
 
long double len2(const point &a) {
    return a.x * a.x + a.y * a.y;
}
 
long double len(const point &a) {
    return sqrtl(a.x * a.x + a.y * a.y);
}
 
long double len_point_segment(point a, point c, point d) {
    if (dp(a - c, d - c) >= 0 && dp(a - d, c - d) >= 0) {
        return abs(cp(a - c, d - c)) * 1.0 / len(d - c);
    } else
        return min(len(a - c), len(a - d));
}
 
bool cmp(point p, point c, point d) {
    point a = c - p;
    point b = d - p;
    return cp(a, b) > 0 || (cp(a, b) == 0 && len2(a) < len2(b));
}
 
int sign(long double a) {
    if (abs(a) < 1e-6) {
        return 0;
    }
 
    if (a > 0) {
        return 1;
    }
    return -1;
}
 
bool is_in_triangle(point a, point b, point c, point my) {
    long double sq = abs(cp((b - a), (c - a)));
    long double new_sq = abs(cp((b - my), (a - my))) + abs(cp((b - my), (c - my))) + abs(cp((a - my), (c - my)));
    return sq == new_sq;
}
 
bool is_in_angle(point a, point b, point c, point my) {
    return sign(cp((b - a), (my - a))) * sign(cp((my - a), (c - a))) >= 0;
}
 
bool is_in_convex(const vector<point> &a, point my) {
    int l = 1, r = a.size() - 1;
 
    if (!is_in_angle(a[0], a[l], a[r], my)) {
        return 0;
    }
 
    while (r - l > 1) {
        int m = (r + l) / 2;
        if (is_in_angle(a[0], a[l], a[m], my)) {
            r = m;
        } else {
            l = m;
        }
    }
 
    return is_in_triangle(a[0], a[l], a[r], my);
}
 
int gi(int i, int n) {
    while (i < 0) {
        i += n;
    }
    return i % n;
}
 
int find_nearest(vector<point> &poly, point curr_point) {
    if (is_in_convex(poly, curr_point)) {
        return -1;
    }
 
    int l = 0;
    int r = poly.size();
 
    while (r - l > 3000) {
        int x1 = (2 * l + r) / 3;
        int x2 = (l + 2 * r) / 3;
 
        if (len2(poly[x1] - curr_point) < len2(poly[x2] - curr_point)) {
            r = x2;
        } else {
            l = x1;
        }
    }
 
    int ans = l;
 
    for (int i = l; i <= r && i < poly.size(); i++) {
        if (len2(poly[i] - curr_point) < len2(poly[ans] - curr_point)) {
            ans = i;
        }
    }
 
    return ans;
}
 
long double find_distance(vector<point> &poly, point curr_point) {
    if (is_in_convex(poly, curr_point)) {
        return 0;
    }
 
    int l = find_nearest(poly, curr_point);
    int prev = l - 1;
    if (prev < 0) {
        prev += poly.size();
    }
 
    int next = (l + 1) % poly.size();
 
    return min(len_point_segment(curr_point, poly[l], poly[prev]), len_point_segment(curr_point, poly[l], poly[next]));
}
 
int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
 
    int n;
    cin >> n;
    vector<point> poly(n);
    for (int i = 0; i < n; ++i) {
        long double x, y;
        cin >> x >> y;
        poly[i] = {x, y};
    }
 
    vector<point> norms(n);
    long double S = 0, P = 0, x0 = 0, y0 = 0;
    for (int i = 0; i < n; ++i) {
        S += cp(poly[i], poly[(i + 1) % n]);
        P += len(poly[i] - poly[(i + 1) % n]);
        norms[i] = {
            poly[(i + i) % n].y - poly[i].y, poly[i].x - poly[(i + 1) % n].x};
        x0 += poly[i].x;
        y0 += poly[i].y;
    }
    S = abs(S / 2);
 
    int q;
    cin >> q;
    vector<pair<point, int>> cities(q);
    for (int i = 0; i < q; ++i) {
        long double x, y;
        cin >> x >> y;
        cities[i] = {{x, y}, i};
    }
 
    sort(cities.begin(), cities.end(), [x0, y0](auto a, auto b){
        return cmp({x0, y0}, a.first, b.first);
    });
     
    long long start = 0;
    long double st_ds = 2e18, ds;
    for(int i = 0; i < n; ++i) {
        if((ds = len_point_segment(cities[0].first, poly[i], poly[(i + 1) % n])) < st_ds) {
            start = i;
            st_ds = ds;
        }
    }
     
    vector<long double> dists(q, 2e18);
    for(int i = 0; i < q; ++i) {
        dists[i] = find_distance(poly, cities[i].first);
    }
 
 
    vector<long double> rs;
    for (unsigned long long i = 0; i < 62; ++i) {
        rs.push_back(
            (-P + sqrtl(P * P + 4 * pi * S * ((1ULL << i) - 1))) / (2 * pi)
        );
    }
 
    vector<int> res(q);
    for (int i = 0; i < q; ++i) {
        if (is_in_convex(poly, cities[i].first)) {
            res[cities[i].second] = 0;
            continue;
        }

        res[cities[i].second] = lower_bound(rs.begin(), rs.end(), dists[i] - 1e-5) - rs.begin();
    }
     
    for(auto e : res) {
        cout << e << '\n';
    }
 
    return 0;
}