#include <iostream>
#include <vector>
#include <queue>

using namespace std;

const int MAXN = 1005;
const int dx[] = { -1, 1, 0, 0, -2, 2, 0, 0 };
const int dy[] = { 0, 0, -1, 1, 0, 0, -2, 2 };

int N, M, K;
vector<string> city;
vector<vector<vector<int>>> dist;

bool isValid(int x, int y) {
    return x >= 0 && x < N && y >= 0 && y < M && city[x][y] == '.';
}

bool canReachAirport(int startX, int startY, int airportX, int airportY) {
    dist.assign(N, vector<vector<int>>(M, vector<int>(K + 1, -1)));
    queue<pair<pair<int, int>, int>> q; // (x, y), remaining jumps

    dist[startX][startY][K] = 0;
    q.push({ {startX, startY}, K });

    while (!q.empty()) {
        int x = q.front().first.first;
        int y = q.front().first.second;
        int k = q.front().second;
        q.pop();

        if (x == airportX && y == airportY) {
            return true;
        }

        for (int i = 0; i < 8; ++i) {
            int nx = x + dx[i];
            int ny = y + dy[i];
            int nk = k - (i >= 4); // Reduce jumps if using MegaJump

            if (isValid(nx, ny) && nk >= 0 && dist[nx][ny][nk] == -1) {
                dist[nx][ny][nk] = dist[x][y][k] + 1;
                q.push({ {nx, ny}, nk });
            }
        }
    }

    return false;
}

int main() {
    cin >> N >> M >> K;
    city.resize(N);
    for (int i = 0; i < N; ++i) {
        cin >> city[i];
    }

    int startX, startY, airportX, airportY;
    cin >> startX >> startY >> airportX >> airportY;
    --startX; --startY; --airportX; --airportY; // Adjust to 0-based indexing

    if (canReachAirport(startX, startY, airportX, airportY)) {
        cout << "YES" << endl;
    }
    else {
        cout << "NO" << endl;
    }

    return 0;
}