import math


def find_centroid(vertices):
    Cx = sum(x for x, y in vertices) / len(vertices)
    Cy = sum(y for x, y in vertices) / len(vertices)

    return Cx, Cy


def is_point_inside_polygon(point, polygon):
    x, y = point
    n = len(polygon)
    inside = False

    p1x, p1y = polygon[0]
    for i in range(1, n + 1):
        p2x, p2y = polygon[i % n]

        if ((p1y == p2y and y == p1y and min(p1x, p2x) <= x <= max(p1x, p2x)) or
                (p1x == p2x and x == p1x and min(p1y, p2y) <= y <= max(p1y, p2y))):
            return True

        if ((p1y > y) != (p2y > y)) and (x <= (p2x - p1x) * (y - p1y) / (p2y - p1y) + p1x):
            inside = not inside

        p1x, p1y = p2x, p2y

    return inside


def is_point_inside_circle(point, circle_center, radius):
    x, y = point
    x_c, y_c = circle_center

    distance_squared = (x - x_c) ** 2 + (y - y_c) ** 2

    return distance_squared <= radius ** 2


def find_polygon_area(vertices):
    n = len(vertices)
    area = 0.0

    for i in range(n):
        x1, y1 = vertices[i]
        x2, y2 = vertices[(i + 1) % n]
        area += (x1 * y2) - (x2 * y1)

    return abs(area) / 2.0


def find_farthest_point_distance(reference_point, points):
    farthest_point = None
    max_distance = -1

    x1, y1 = reference_point

    for point in points:
        x2, y2 = point
        distance = math.sqrt((x2 - x1) ** 2 + (y2 - y1) ** 2)
        if distance > max_distance:
            max_distance = distance
            farthest_point = point

    return max_distance


def process():
    verticles = []
    colonies = []
    for _ in range(int(input())):
        verticles.append(list(map(int, input().split())))
    for _ in range(int(input())):
        colonies.append(list(map(int, input().split())))

    colony_is_corrupted = [-1 for _ in range(len(colonies))]

    centroid = find_centroid(verticles)
    start_area = find_polygon_area(verticles)

    for i in range(len(colonies)):
        if is_point_inside_polygon(colonies[i], verticles):
            colony_is_corrupted[i] = 0

    new_radius = math.sqrt(2 / math.pi * start_area)
    for i in range(len(colonies)):
        if colony_is_corrupted[i] == -1:
            if is_point_inside_circle(colonies[i], centroid, new_radius):
                colony_is_corrupted[i] = 1

    step = 1
    while True:
        step += 1
        new_radius = math.sqrt(2 * new_radius * new_radius)

        not_corrupted_any = 0
        for i in range(len(colonies)):
            if colony_is_corrupted[i] == -1:
                if is_point_inside_circle(colonies[i], centroid, new_radius):
                    colony_is_corrupted[i] = step
                else:
                    not_corrupted_any = 1
        if not not_corrupted_any:
            break

    for i in colony_is_corrupted:
        print(i)


if __name__ == "__main__":
    process()