#include <iostream>
#include <cmath>
#include <algorithm>
#include <vector>
#include <cassert>
#include <set>

using namespace std;

vector<pair<int, int>> ans;

int get_size(const vector<vector<int>>& g, int v) {
  int sz = 1;
  for (int u : g[v]) {
    if (u != -1) sz += get_size(g, u);
  }
  return sz;
}

void deletion_order(const vector<vector<int>>& g, int v, vector<int>& order) {
  for (int u : g[v]) {
    if (u != -1) deletion_order(g, u, order);
  }
  order.push_back(v);
}

void match(vector<vector<int>> &g1, const vector<vector<int>> &g2, vector<int> &p1, int v1, int v2) {
  int l1 = 0;
  int l2 = 0;
  vector<int> l_order, r_order;

  if (g1[v1][0] != -1) {
    deletion_order(g1, g1[v1][0], l_order);
    reverse(l_order.begin(), l_order.end());
    l1 = get_size(g1, g1[v1][0]);
    assert(l1 == l_order.size());
  }
  if (g1[v1][1] != -1) {
    deletion_order(g1, g1[v1][1], r_order);
    reverse(r_order.begin(), r_order.end());
  }

  if (g2[v2][0] != -1) {
    l2 = get_size(g2, g2[v2][0]);
  }

  int pod_right = v1;
  while (g1[pod_right][1] != -1) {
    pod_right = g1[pod_right][1];
  }

  while (l1 > l2) {
    int leaf = l_order.back();
    l_order.pop_back();

    if (g1[p1[leaf]][0] != leaf) g1[p1[leaf]][1] = -1;
    else g1[p1[leaf]][0] = -1;

    p1[leaf] = pod_right;
    ans.push_back({ leaf, pod_right });

    g1[pod_right][1] = leaf;
    pod_right = leaf;

    l1--;
  }

  int pod_left = v1;
  while (g1[pod_left][0] != -1) {
    pod_left = g1[pod_left][0];
  }

  while (l2 > l1) {
    int leaf = r_order.back();
    r_order.pop_back();

    if (g1[p1[leaf]][0] != leaf) g1[p1[leaf]][1] = -1;
    else g1[p1[leaf]][0] = -1;

    p1[leaf] = pod_left;
    ans.push_back({ leaf, pod_left });

    g1[pod_left][0] = leaf;
    pod_left = leaf;

    l1++;
  }

  if (g1[v1][0] != -1) {
    match(g1, g2, p1, g1[v1][0], g2[v2][0]);
  }
  if (g1[v1][1] != -1) {
    match(g1, g2, p1, g1[v1][1], g2[v2][1]);
  }
}

int main() {
  ios::sync_with_stdio(0);
  cin.tie(0), cout.tie(0);

  int n;
  cin >> n;
  vector<int> p1(n), p2(n);
  vector<vector<int>> g1(n), g2(n);
  for (int i = 1; i < n; ++i) {
    cin >> p1[i];
    g1[p1[i]].push_back(i);
  }
  for (int i = 1; i < n; ++i) {
    cin >> p2[i];
    g2[p2[i]].push_back(i);
  }

  for (int i = 0; i < n; i++) {
    while (g1[i].size() < 2) g1[i].push_back(-1);
    while (g2[i].size() < 2) g2[i].push_back(-1);
  }
 
  match(g1, g2, p1, 0, 0);

  vector<pair<int, int>> result;
  set<int>met;
  for (int i = (int)ans.size() - 1; i >=0; i--) {
    if (met.count(ans[i].first)) {
      continue;
    }
    result.push_back(ans[i]);
    met.insert(ans[i].first);
  }
  reverse(result.begin(), result.end());
  
  cout << ans.size() << "\n";
  for (auto x : ans) {
    cout << x.first << " " << x.second << "\n";
  }

  return 0;
}
