#include <iostream>
#include <algorithm>
#include <vector>
#include <iomanip>
#include <map>
#include <set>
#include <fstream>
#include <string>
#include <bitset>
#include <ctime>
#include <random>
#include <iterator>
#include <cmath>
#include <queue>
#include <deque>
#include <time.h>

// #define cin fin
// #define cout fout

using namespace std;

#define all(a) a.begin(), a.end()
#define rsort(a) sort(a, [&](auto b, auto c) {return b > c;})

ifstream fin("input.txt");
ofstream fout("output.txt");

using ll = long long;
using ld = long double;
using ull = unsigned long long;

ll const inf = 1e18;

template <class T>
istream& operator>> (istream& in, vector<T>& a)
{
	for (T& e : a)
		in >> e;
	return in;
}

template <class T>
ostream& operator<< (ostream& out, const vector<T>& a)
{
	for (const T& e : a)
		out << e << " ";
	return out;
}

template<class T, class N> auto min(T a, N b)
{
	return sizeof(a) > sizeof(b) ? min(a, (T)b) : min((N)a, b);
}

template<class T, class N> auto max(T a, N b)
{
	return sizeof(a) > sizeof(b) ? max(a, (T)b) : max((N)a, b);
}

random_device rd;
mt19937 mersenne(rd());

ll mod = 1e9 + 7;

struct Tree {
	vector<ll> p{};
	vector<set<ll>> a{};
	ll n = 0;
};

// take v and go to u
void repl(Tree& t, ll v, ll u, vector<pair<ll, ll>>& ans)
{
	ll pv = t.p[v];
	t.a[pv].erase(v);
	t.p[v] = u;
	t.a[u].insert(v);
	ans.push_back({ v, u });
}

bool to_bambook_step(Tree& t, vector<pair<ll, ll>>& ans)
{
	ll u = 0;
	for (int i = 0; i < t.n; ++i)
	{
		if (t.a[i].empty())
		{
			u = i;
		}
	}
	ll ppv = t.p[u];
	ll pv = u;
	while (ppv != -1)
	{
		if (t.a[ppv].size() == 2)
		{
			ll v = *t.a[ppv].begin() + *t.a[ppv].rbegin() - pv;
			repl(t, v, u, ans);
			return true;
		}
		pv = ppv;
		ppv = t.p[ppv];
	}
	return false;
}

void to_bambook(Tree& t, vector<pair<ll, ll>>& ans)
{
	while (to_bambook_step(t, ans)) {}
}


ll sub_tree_size(Tree& s, ll sv)
{
	if (s.a[sv].size() == 0)
	{
		return 1;
	}
	if (s.a[sv].size() == 1)
	{
		return 1 + sub_tree_size(s, * s.a[sv].begin());
	}
	if (s.a[sv].size() == 2)
	{
		ll sv1 = *s.a[sv].begin();
		ll sv2 = *s.a[sv].rbegin();

		return 1 + sub_tree_size(s, sv1) + sub_tree_size(s, sv2);
	}
}


void bambook_to_tree(Tree& t, ll tv, Tree& s, ll sv, vector<pair<ll, ll>>& ans)
{
	if (s.a[sv].size() == 0)
	{
		return;
	}
	if (s.a[sv].size() == 1)
	{
		bambook_to_tree(t, *t.a[tv].begin(), s, *s.a[sv].begin(), ans);
	}
	if (s.a[sv].size() == 2)
	{
		ll sv1 = *s.a[sv].begin();
		ll sv2 = *s.a[sv].rbegin();
		ll tv1 = *t.a[tv].begin();

		ll size1 = sub_tree_size(s, sv1);

		ll tvv = tv;
		for (int i = 0; i <= size1; ++i)
		{
			tvv = *t.a[tvv].begin();
		}
		repl(t, tvv, tv, ans);
		ll tv2 = tvv;
		bambook_to_tree(t, tv1, s, sv1, ans);
		bambook_to_tree(t, tv2, s, sv2, ans);
	}
}

void solve()
{
	ll n; cin >> n;
	
	Tree t1;
	t1.p.assign(n, -1);
	t1.a.assign(n, {});
	t1.n = n;
	Tree t2;
	t2.p.assign(n, -1);
	t2.a.assign(n, {});
	t2.n = n;
	for (int i = 1; i < n; ++i)
	{
		ll p; cin >> p;
		t1.p[i] = p;
		t1.a[p].insert(i);
	}

	for (int i = 1; i < n; ++i)
	{
		ll p; cin >> p;
		t2.p[i] = p;
		t2.a[p].insert(i);
	}

	vector<pair<ll, ll>> ans;

	to_bambook(t1, ans);
	bambook_to_tree(t1, 0, t2, 0, ans);
	cout << ans.size() << '\n';
	for (int i = 0; i < ans.size(); ++i)
	{
		cout << ans[i].first << " " << ans[i].second << '\n';
	}
}

//#define TIME
#define ONCE

signed main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);

	ll TT = 1;
#ifndef ONCE 
	cin >> TT;
#endif
	while (TT--)
	{
#ifdef TIME
		clock_t start, end;

		start = clock();
#endif
		solve();
#ifdef TIME
		end = clock();

		cerr << "\ntime: " << ((double)end - start) / ((double)CLOCKS_PER_SEC) << " s\n";
#endif
		cerr << '\n';
	}
	return 0;
}
