#define _CRT_SECURE_NO_WARNINGS
#define INF 1e9
#define ACC 1e-6
#define FAC_10 3628800
#define ll long long

#include <cassert>
#include <algorithm>
#include <iostream>
#include <string>
#include <iomanip>
#include <cmath>
#include <algorithm>
#include <cstdio>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <random>
#include <numeric>

using namespace std;

struct Step
{
    int row;
    int col;
    bool cost;
};


struct Point
{
    int row;
    int col;
    bool not_wall;
    int id;
};

Point operator+(const Point& fst, const Point& snd) {
    return { fst.row + snd.row, fst.col + snd.col, fst.not_wall, fst.id };
}

struct Edge {
    Point to;
    bool w;
    Edge(Point to, bool w) : to(to), w(w) {}
};

void bfs01(const vector<vector<Edge>>& g, int st, vector<int>& d) {
    deque<int> q;
    q.push_back(st);
    d[st] = 0;
    while (!q.empty()) {
        int cur = q.front();
        q.pop_front();
        for (const Edge& e : g[cur]) {
            if (d[cur] + e.w >= d[e.to.id])
                continue;
            d[e.to.id] = d[cur] + e.w;
            if (e.w == 0)
                q.push_front(e.to.id);
            else
                q.push_back(e.to.id);
        }
    }
}

vector<Step> steps = { {0, 1, false}, {0, -1, false}, {1, 0, false}, {-1, 0, false},  {0, 2, true}, {0, -2, true}, {2, 0, true}, {-2, 0, true}};

int main() {
#ifdef _DEBUG
    freopen("input.txt", "r", stdin);
#endif
    ios::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);

    int n, m, k;
    cin >> n >> m >> k;

    vector<vector<Point>> inp(n + 4, vector<Point>(m + 4));
    int id = 0;

    for (int i = 2; i < n + 2; i++)
        for (int j = 2; j < m + 2; j++) {
            char cell;
            cin >> cell;
            if (cell == '.')
                inp[i][j] = { i, j, true, id };
            else if (cell == '#')
                inp[i][j] = { i, j, false, id };
            id++;
        }

    Point st, fn;
    cin >> st.row >> st.col;
    cin >> fn.row >> fn.col;
    vector<vector<Edge>> g(n * m);

    for (int i = 2; i < n + 2; i++)
        for (int j = 2; j < m + 2; j++) {
            Point cur = inp[i][j];
            for (int t = 0; t < steps.size(); t++) {
                Step cur_step = steps[t];
                if (inp[i + cur_step.row][j + cur_step.col].not_wall)
                    g[cur.id].push_back({ inp[i + cur_step.row][j + cur_step.col], cur_step.cost });
            }
        }

    vector<int> dist(n * m, INF);
    bfs01(g, inp[st.row + 1][st.col + 1].id, dist);
    int res = dist[inp[fn.row + 1][fn.col + 1].id];
    if (res > k)
        cout << "NO";
    else
        cout << "YES";


}
