﻿#include <iostream>
#include <iomanip>
#include <algorithm>
#include <vector>
#include <cmath>
#include <map>
#include <sstream>
#include <numeric>
#include <queue>

using namespace std;

#define int long long

const int inf = 1LL << 60;
const int mod = 1000000007;
const double pi = 3.141592653589793238462643383279502884;

template<typename T1, typename T2>
ostream& operator<<(ostream& s, pair<T1, T2>& p) {
    s << "(" << p.first << ", " << p.second << ")";
    return s;
}

template<typename T>
ostream& operator<<(ostream& s, vector<T>& a) {
    for (T x : a) s << x << " ";
    s << endl;
    return s;
}

struct point {
    double x, y;
    point() { x = 0; y = 0; }
    point(double x_, double y_) { x = x_; y = y_; }
};

ostream& operator<<(ostream& s, point& p) {
    s << "(" << p.x << ", " << p.y << ")";
    return s;
}

double angle(point& p1, point& p2) {
    double x = atan2(p2.y - p1.y,p2.x - p1.x);
    if (x < 0) x += 2 * pi;
    return x;
}

double dist(point& p, point& a, point& b) {
    double t = ((p.x - a.x) * (b.x - a.x) + (p.y - a.y) * (b.y - a.y)) / ((b.x - a.x) * (b.x - a.x) + (b.y - a.y) * (b.y - a.y));
    if (t < 0) t = 0;
    if (t > 1) t = 1;
    double x1 = (a.x - p.x + (b.x - a.x) * t);
    double y1 = (a.y - p.y + (b.y - a.y) * t);
    return sqrt(x1 * x1 + y1 * y1);
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout << fixed << setprecision(10);
    
    /* ---------- 1. input ---------- */
    int n;
    cin >> n;
    vector<point> start(n);
    for (int i = 0; i < n; i++)
        cin >> start[i].x >> start[i].y;
    start.push_back(start[0]);
    int q;
    cin >> q;
    vector<point> villages(n);
    for (int i = 0; i < n; i++)
        cin >> villages[i].x >> villages[i].y;

    /* ---------- 2. calculate d(t) ---------- */
    // 2.1. calculate s and l
    double s = 0, sl = 0;
    for (int i = 0; i < n; i++) {
        int j = (i + 1) % n;
        int x1 = start[i].x - start[j].x, x2 = start[i].y - start[j].y;
        sl += sqrt(x1 * x1 + x2 * x2);
        s += (start[i].x - start[j].x) * (start[i].y + start[j].y);
    }
    s = abs(s) / 2;
    
    // 2.2. calculate d(t)
    vector<double> d_t;
    d_t.push_back(0);
    double s_desired = s;
    while (d_t[d_t.size() - 1] <= 2000000000) {
        s_desired *= 2;
        double l = d_t[d_t.size() - 1], r = 1e10;
        for (int i = 0; i < 100; i++) {
            double m = (l + r) / 2;
            double s_actual = s + sl * m + pi * m * m;
            if (s_actual < s_desired)
                l = m;
            else
                r = m;
        }
        d_t.push_back(l);
    }
    //cout << d_t;

    /* ---------- 3. preparation ---------- */
    // 3.1. select center point
    point center;
    if (n == 3) {
        center.x = (start[0].x + start[1].x + start[2].x) / 3;
        center.y = (start[0].y + start[1].y + start[2].y) / 3;
    }
    else {
        center.x = (start[0].x + start[n / 2].x) / 2;
        center.y = (start[0].y + start[n / 2].y) / 2;
    }

    // 3.2. shift initial so that n-1 <-> 0 intersects direction
    vector<point> start_shifted(n + 2);
    for (int i = 0; i < n; i++) {
        if ((start[i].y < center.y) && (start[i + 1].y >= center.y)) {
            start_shifted[0] = start[i];
            for (int j = 1; j <= n; j++) {
                start_shifted[j] = start[(j + i) % n];
            }
            start_shifted[n + 1] = start[(i + 1) % n];
            start = start_shifted;
            break;
        }
    }

    // 3.3. store angle for each point
    vector<double> angles(n + 2);
    for (int i = 0; i < n + 2; i++) {
        angles[i] = angle(center, start[i]);
        //cout << center.x << " " << center.y << " " << start[i].x << " " << start[i].y << " " << angles[i] << endl;
    }
    angles[0] -= pi * 2;
    angles[n + 1] += pi * 2;
    //cout << angles;

    /* ---------- 4. solve for each point ---------- */
    for (point& village : villages) {
        // 4.1. get sector in which it lies
        double a = angle(center, village);
        int i = distance(angles.begin(), lower_bound(angles.begin(), angles.end(), a));
        point l2 = start[(i - 2 + n) % n], l = start[i - 1], r = start[i], r2 = start[(i + 1) % n];

        // 4.2. if inside, return 0
        int s = (l.x - r.x) * (village.y - r.y) - (l.y - r.y) * (village.x - r.x);
        if (s <= 0) {
            cout << 0 << endl;
            continue;
        }

        double d = min(min(dist(village, l2, l),
                        dist(village, l, r)),
                        dist(village, r, r2));
        int day = distance(d_t.begin(), lower_bound(d_t.begin(), d_t.end(), d));
        cout << day << endl;
    }
}