#include <cstdint>
#include <iostream>
#include <queue>
#include <vector>

using i64 = int64_t;
using u64 = uint64_t;
using i32 = int32_t;
using u32 = uint32_t;
using i16 = int16_t;
using u16 = uint16_t;
using i8 = int8_t;
using u8 = uint8_t;

using namespace std;

struct Point {
  i32 x, y;
};

vector<pair<Point, i32>> neighbors(Point point, i32 K) {
  if (K >= 1) {
    return {{{point.x + 1, point.y}, K},     {{point.x - 1, point.y}, K},
            {{point.x, point.y + 1}, K},     {{point.x, point.y - 1}, K},
            {{point.x + 2, point.y}, K - 1}, {{point.x - 2, point.y}, K - 1},
            {{point.x, point.y + 2}, K - 1}, {{point.x, point.y - 2}, K - 1}};
  } else {
    return {{{point.x + 1, point.y}, 0},
            {{point.x - 1, point.y}, 0},
            {{point.x, point.y + 1}, 0},
            {{point.x, point.y - 1}, 0}};
  }
}

bool bfs(vector<vector<bool>> map, Point init, i32 initK, Point end) {
  vector<vector<i32>> ks{map.size(), vector<i32>(map[0].size(), -1)};
  ks[init.x][init.y] = initK;
  queue<Point> q;
  q.push(init);
  while (!q.empty()) {
    Point front = q.front();
    q.pop();
    if (front.x == end.x && front.y == end.y) {
      return true;
    }
    if (front.x < 0 || front.x >= map.size() || front.y < 0 ||
        front.y >= map[0].size()) {
      continue;
    }
    if (!map[front.x][front.y]) {
      continue;
    }
    for (auto [p, k] : neighbors(front, ks[front.x][front.y])) {
      if (p.x < 0 || p.x >= map.size() || p.y < 0 || p.y >= map[0].size()) {
        continue;
      }
      if (ks[p.x][p.y] <= k) {
        q.push(p);
        ks[p.x][p.y] = k;
      }
    }
  }

  return false;
}

int main() {
  i32 N, M, K;
  cin >> N >> M >> K;
  vector<vector<bool>> map{(u32)N, vector<bool>(M)};
  for (i32 x = 0; x < N; x++) {
    string s;
    cin >> s;
    for (i32 y = 0; y < M; y++) {
      map.at(x).at(y) = s.at(y) == '.';
    }
  }

  Point init, end;
  cin >> init.x >> init.y >> end.x >> end.y;
  init.x--;
  init.y--;
  end.x--;
  end.y--;

  cout << (bfs(map, init, K, end) ? "yes" : "no") << endl;
}
