// #define _GLIBCXX_DEBUG 1
#include <bits/stdc++.h>
using namespace std;

typedef long long ll;
typedef long double ld;
using pii = pair<int, int>;
using pll = pair<ll, ll>;
#if LOCAL
#define dbg(o) ({ cout << #o << " = " << (o) << "\n"; o; })
#else
#define dbg(o) (o)
#endif

#define ff first
#define ss second
#define len(a) (int)a.size()
#define all(x) x.begin(), x.end()
#define rall(x) x.rbegin(), x.rend()

mt19937_64 rnd(chrono::steady_clock::now().time_since_epoch().count());
ll rng(ll l, ll r) { return uniform_int_distribution<ll> (l, r) (rnd); }

void vendory() {}

const ld EPS = 1e-9;

struct point {
    ld x = 0, y = 0;

    point() {}

    point(ld x, ld y) : x(x), y(y) {}

    bool operator<(const point &p) const {
        return x < p.x - EPS || (abs(x - p.x) < EPS && y < p.y - EPS);
    }

    bool operator>(const point &p) const {
        return x > p.x + EPS || (abs(x - p.x) < EPS && y > p.y + EPS);
    }

    bool operator==(const point &p) const {
        return abs(x - p.x) < EPS && abs(y - p.y) < EPS;
    }

    point operator+(const point &p) const {
        return point(x + p.x, y + p.y);
    }

    point operator-(const point &p) const {
        return point(x - p.x, y - p.y);
    }

    point operator*(const ld &k) const {
        return point(x * k, y * k);
    }

    point operator/(const ld &k) const {
        return point(x / k, y / k);
    }

    ld operator*(const point &p) const {
        return x * p.x + y * p.y;
    }

    ld operator%(const point &p) const {
        return x * p.y - y * p.x;
    }

    point left() const {
        return point(-y, x);
    }

    ld lengthsqr() const {
        return x * x + y * y;
    }

    ld length() const {
        return sqrt(this->lengthsqr());
    }

    ld dist(const point &p) const {
        return (*this - p).length();
    }
};

ostream &operator<<(ostream &out, const point &p) {
    return out << p.x << ' ' << p.y;
}

istream &operator>>(istream &in, point &p) {
    return in >> p.x >> p.y;
}

struct matrix {
    vector <vector<ld>> m = {{1, 0},
                             {0, 1}};

    matrix() {}

    matrix(vector <vector<ld>> m) : m(std::move(m)) {}

    matrix(ld phi) : m({{cos(phi), -sin(phi)},
                        {sin(phi), cos(phi)}}) {}

    matrix operator*(const matrix &b) const {
        matrix c;
        for (int i = 0; i < 2; ++i) {
            for (int j = 0; j < 2; ++j) {
                for (int k = 0; k < 2; ++k) {
                    c.m[i][j] += m[i][k] * b.m[k][j];
                }
            }
        }
        return c;
    }

    point operator*(const point &p) const {
        return point(m[0][0] * p.x + m[0][1] * p.y, m[1][0] * p.x + m[1][1] * p.y);
    }
};

struct line {
    point p = point(), d = point();

    line() {}

    line(point p, point d) : p(p), d(d) {}

    line(ld a, ld b, ld c) : p(point(-a * c / (a * a + b * b), -b * c / (a * a + b * b))), d(point(-b, a)) {}

    ld dist(point a) const {
        return d % (a - p) / d.length();
    }

    bool parallel(const line &l) const {
        return abs(d % l.d) < EPS;
    }

    ld t(const line &l) const {
        return (l.p - p) % l.d / (d % l.d);
    }

    ld lt(const line &l) const {
        return (p - l.p) % d / (l.d % d);
    }

    point operator()(ld t) const {
        return p + d * t;
    }

    bool intersects(const line &l) const { // segment intersection
        return !parallel(l) && -EPS < lt(l) && lt(l) < 1 + EPS;
    }

    point intersect(const line &l) const {
        return p + d * t(l);
    }
};

ostream &operator<<(ostream &out, const line &l) {
    return out << l.p << " + " << l.d << "t";
}

istream &operator>>(istream &in, line &l) {
    return in >> l.p >> l.d;
}

struct polygon {
    vector <point> p;

    polygon() {}

    polygon(vector <point> p) : p(p) {}

    polygon convex_hull() {
        vector <point> h;
        sort(all(p));
        for (int i = 0; i < len(p); ++i) {
            while (len(h) >= 2 && (h[len(h) - 1] - h[len(h) - 2]) % (p[i] - h[len(h) - 2]) < EPS) {
                h.pop_back();
            }
            h.push_back(p[i]);
        }
        for (int i = len(p) - 2, t = len(h) + 1; i >= 0; --i) {
            while (len(h) >= t && (h[len(h) - 1] - h[len(h) - 2]) % (p[i] - h[len(h) - 2]) < EPS) {
                h.pop_back();
            }
            h.push_back(p[i]);
        }
        h.pop_back();
        return polygon(h);
    }

    ld area() const {
        ld s = 0;
        for (int i = 0; i < len(p); ++i) {
            s += p[i] % p[(i + 1) % len(p)];
        }
        return s / 2;
    }

    vector <line> sides() {
        vector <line> s;
        for (int i = 0; i < len(p); ++i) {
            s.push_back(line(p[i], p[(i + 1) % len(p)] - p[i]));
        }
        return s;
    }

    bool in(point p) {
        vector <line> s = sides();
        line nice = line(p, point(69, 420));
        int cnt = 0;
        for (int i = 0; i < len(s); ++i) {
            cnt += nice.intersects(s[i]) && nice.t(s[i]) > -EPS;
        }
        return cnt & 1;
    }

    bool onBorder(point p) {
        vector <line> s = sides();
        for (int i = 0; i < len(s); ++i) {
            line a(p, s[i].d.left());
            if (a.d.length() > EPS && abs(s[i].dist(p)) < EPS && a.intersects(s[i])) {
                return true;
            } else if (p == s[i].p) {
                return true;
            }
        }
        return false;
    }
};

void sol() {
    int n;
    cin >> n;
    vector<point> a(n);
    for (auto &e : a) cin >> e;
    polygon p(a);
    // p.convex_hull();
    int q;
    cin >> q;
    vector<point> b(q);
    for (auto &e : b) cin >> e;
    for (auto pt : b) {
        auto dir = p.p[0] - pt;
        int l = 0, r = n;
        int lans, rans;
        if (dir % (p.p[1] - pt) > 0) {
            while (r - l > 1) {
                int m = (l + r) / 2;
                if (dir % (p.p[m] - pt) > 0) l = m;
                else r = m;
            }
            int l1 = 0, r1 = l;
            while (r1 - l1 > 1) {
                int m = (l1 + r1) / 2;
                if ((p.p[l1 % m] - pt) % (p.p[m % n] - pt) > 0) l1 = m;
                else r1 = m;
            }
            lans = r1;
            int l2 = l, r2 = n;
            while (r2 - l2 > 1) {
                int m = (l2 + r2) / 2;
                if ((p.p[r1 % n] - pt) % (p.p[m % n] - pt) > 0) l2 = m;
                else r2 = m;
            }
            rans = r2;
        } else {
            while (r - l > 1) {
                int m = (l + r) / 2;
                if (dir % (p.p[m] - pt) < 0) l = m;
                else r = m;
            }
            int l1 = 0, r1 = l;
            while (r1 - l1 > 1) {
                int m = (l1 + r1) / 2;
                if ((p.p[l1 % m] - pt) % (p.p[m % n] - pt) > 0) l1 = m;
                else r1 = m;
            }
            lans = r1;
            int l2 = l, r2 = n;
            while (r2 - l2 > 1) {
                int m = (l2 + r2) / 2;
                if ((p.p[r1 % n] - pt) % (p.p[m % n] - pt) > 0) l2 = m;
                else r2 = m;
            }
            rans = r2;
        }
        cout << pt << '\n' << p.p[lans % n] << ' ' << p.p[rans % n] << endl;
    }
    for (auto e : p.p) cout << e << '\n';
}

int32_t main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
#if LOCAL
    freopen("../A/input.txt", "r", stdin);
    vendory();
    int q;
    cin >> q;
    for (int i = 0; i < q; ++i) {
        cout << "\n================================ " << i << " ================================" << endl;
        sol();
    }
#else
    vendory();
    sol();
#endif
    return (0-0);  // <3
}

// amogus