#include <iostream>
#include <cstdint>
#include <vector>
#include <utility>
#include <array>
#include <deque>

using namespace std;

struct Node;
using NodePtr = Node *;
using Weight = size_t;

struct Node {
    Node(char symbol) : alive{symbol == '.'} {}

    bool alive;
    bool used{false};
    size_t dist{1000001};
    vector<pair<NodePtr, Weight>> connections;
};

using Row = vector<Node>;
using Graph = vector<Row>;

bool validate(int32_t i, int32_t j, int32_t N, int32_t M) {
    return i >= 0 && j >= 0 && i < N && j < M;
}

int main() {
    cin.tie(nullptr);
    cout.tie(nullptr);
    ios_base::sync_with_stdio(false);

    int32_t N, M, K;
    cin >> N >> M >> K;
    Graph graph(N);
    for (int32_t i = 0; i < N; ++i) {
        graph[i].reserve(M);
        for (int32_t j = 0; j < M; ++j) {
            char current;
            cin >> current;
            graph[i].push_back(Node(current));
        }
    }

    for (int32_t i = 0; i < N; ++i) {
        for (int32_t j = 0; j < M; ++j) {
            if (!graph[i][j].alive) {
                continue;
            }

            array<pair<int32_t, int32_t>, 4> light{{{i - 1, j}, {i + 1, j}, {i, j - 1}, {i, j + 1}}};
            for (const auto [l, r]: light) {
                if (validate(l, r, N, M) && graph[l][r].alive) {
                    graph[i][j].connections.push_back({&graph[l][r], 0});
                }
            }

            array<pair<int32_t, int32_t>, 4> heavy{{{i - 2, j}, {i + 2, j}, {i, j - 2}, {i, j + 2}}};
            for (const auto [l, r]: heavy) {
                if (validate(l, r, N, M) && graph[l][r].alive) {
                    graph[i][j].connections.push_back({&graph[l][r], 1});
                }
            }
        }
    }

    size_t d_x, d_y, a_x, a_y;
    cin >> d_x >> d_y >> a_x >> a_y;
    NodePtr from = &graph[d_x - 1][d_y - 1];
    from->dist = 0;
    NodePtr to = &graph[a_x - 1][a_y - 1];

    deque<NodePtr> q;
    q.push_front(from);
    while (!q.empty()) {
        auto current = q.front();
        q.pop_front();

        if (current == to) {
            if (current->dist <= K) {
                cout << "YES";
            } else {
                cout << "NO";
            }
            return 0;
        }

        if (current->used) {
            continue;
        }
        current->used = true;

        for (auto [neighbour, edge]: current->connections) {
            if (neighbour->used) {
                continue;
            }
            size_t updated_dist = current->dist + edge;
            if (updated_dist < neighbour->dist) {
                neighbour->dist = updated_dist;
                if (edge == 0) {
                    q.push_front(neighbour);
                } else {
                    q.push_back(neighbour);
                }
            }
        }
    }
    cout << "NO"; // ??
    return 0;
}
