#include <iostream>
#include <utility>
#include <cstdint>
#include <vector>
#include <unordered_map>
#include <cassert>

using namespace std;

struct Node;
using NodePtr = Node *;

struct Node {
    NodePtr parent{nullptr};
    NodePtr left{nullptr};
    NodePtr right{nullptr};
    NodePtr rightmost_leaf{nullptr};
    size_t index{0};
};

void update_rightmost_leaf(NodePtr current, NodePtr new_value) {
    current->rightmost_leaf = new_value;
    auto parent = current->parent;
    if (parent == nullptr) {
        return;
    }
    if (parent->right == current || parent->right == nullptr) {
//        assert((parent->right == nullptr) ? (parent->left == current) : true);
        update_rightmost_leaf(parent, new_value);
    }
}

void read_tree(vector<Node> &tree, size_t N) {
    for (size_t i = 1; i < N; ++i) {
        NodePtr current = &tree[i];
        current->index = i;

        size_t parent_idx;
        cin >> parent_idx;
        current->parent = &tree[parent_idx];

        if (tree[parent_idx].left == nullptr) {
            tree[parent_idx].left = current;
        } else {
            tree[parent_idx].right = current;
        }

        if (current->right == nullptr) {
            swap(current->left, current->right);
        }
        NodePtr new_rightmost_leaf = current;
        if (current->right != nullptr) {
            new_rightmost_leaf = current->right->rightmost_leaf;
        } else if (current->left != nullptr) {
            new_rightmost_leaf = current->left->rightmost_leaf;
        }
        update_rightmost_leaf(current, new_rightmost_leaf);
    }
}

struct Step {
    NodePtr a;
    NodePtr b;
    NodePtr a_parent;
};

void solve(NodePtr root, vector<Step> &solution) {
//    assert(root != nullptr);

    if (root->right == nullptr) {
        swap(root->left, root->right);
    }

    if (root->left == nullptr) {
        if (root->right != nullptr) {
            solve(root->right, solution);
        }
        return;
    }

    NodePtr subtree = root->left;
    NodePtr target_vertex = root->rightmost_leaf;
//    assert(subtree != target_vertex);
//
//    assert(subtree != nullptr);
//    assert(target_vertex != nullptr);
//    assert(target_vertex->left == nullptr);
//    assert(target_vertex->right == nullptr);

    solution.push_back({subtree, target_vertex, root});

    target_vertex->right = subtree; /////
    subtree->parent = target_vertex;
    root->left = nullptr;

    update_rightmost_leaf(target_vertex, subtree->rightmost_leaf);
//    assert(root->right != nullptr);
    solve(root->right, solution);
}

int main() {
    cin.tie(nullptr);
    cout.tie(nullptr);
    ios_base::sync_with_stdio(false);

    size_t N;
    cin >> N;

    vector<Node> tree1(N), tree2(N);
    read_tree(tree1, N);
    read_tree(tree2, N);

    vector<Step> part1;
    part1.reserve(N / 2);
    auto root1 = &tree1[0];

    solve(root1, part1);

    vector<Step> part2;
    part2.reserve(N / 2);
    auto root2 = &tree2[0];

    solve(root2, part2);

//    cout << "size of part1: " << part1.size() << endl;
    cout << part1.size() + part2.size() << endl;
    for (const auto &[a, b, parent]: part1) {
//        cout << "step in part1:" << endl;
        cout << a->index << ' ' << b->index << endl;
    }

    unordered_map<size_t, size_t> renaming;
    renaming.reserve(N);
    for (auto curr1 = root1, curr2 = root2; curr1 != nullptr; curr1 = curr1->right, curr2 = curr2->right) {
        renaming[curr2->index] = curr1->index;
    }

//    cout << "size of part2: " << part2.size() << endl;
    for (auto it = part2.rbegin(); it != part2.rend(); ++it) {
        const auto &[a, b, parent] = *it;
//        cout << "step in part2:" << endl;
        cout << renaming[a->index] << ' ' << renaming[parent->index] << endl;
    }

    return 0;
}
