#include <iostream>
#include <vector>
#include <algorithm>
#include <utility>
#include <cmath>

#define int long long

using namespace std;


struct Point {
    double x, y;
};

bool fun1(Point a, Point b, Point c) {
    return a.x*(b.y-c.y)+b.x*(c.y-a.y)+c.x*(a.y-b.y) < 0;
}

bool fun2(Point a, Point b, Point c) {
    return a.x*(b.y-c.y)+b.x*(c.y-a.y)+c.x*(a.y-b.y) > 0;
}

vector<Point> convex_hull (vector<Point> & a) {
    if (a.size() == 1)
        return a;
    sort (a.begin(), a.end(), [&](Point c, Point b){
        return c.x <= b.x && c.y <= b.y;
    });

    Point p1 = a[0],  p2 = a.back();

    vector<Point> up;
    up.push_back (p1);

    vector<Point> down;
    down.push_back (p1);

    for (int i = 1; i < a.size(); ++i) {
        if (i == a.size() - 1 || fun1(p1, a[i], p2)) {
            while (up.size() >= 2 && !fun1(up[up.size() - 2], up[up.size() - 1], a[i])) {
                up.pop_back();
            }
            up.push_back (a[i]);
        }
        if (i == a.size() - 1 || fun2(p1, a[i], p2)) {
            while (down.size() >= 2 && !fun2(down[down.size() - 2], down[down.size() - 1], a[i])) {
                down.pop_back();
            }
            down.push_back (a[i]);
        }
    }
    vector<Point> result;
    for (int i = 0; i < up.size(); ++i) {
        result.push_back(up[i]);
    }

    for (int i = down.size() - 2; i > 0; --i) {
        result.push_back(down[i]);
    }

    return result;
}

double dist(Point p1, Point p2){
    return sqrt(pow((p1.x - p2.x),2) + pow((p1.y-p2.y),2));
}

void Solve() {
    int n;
    cin >> n;
    vector<Point> a;
    double s = 0;
    double mx = 0;
    for(int i = 0; i < n; i++){
        int x1, y1;
        cin >> x1 >> y1;
        Point v;
        v.x = x1;
        v.y = y1;
        a.push_back(v);
        if (i > 0) {
            double d = dist(a[i], a[i - 1]);
            mx = max(mx, d);
            s += d;
        }
        if (i == n - 1) {
            double d = dist(a[0], a[n - 1]);
            s += d;
            mx = max(mx, d);
        }
    }
//    cout << s << " " << mx << "\n";
    cout << s - mx << "\n";
//    vector<Point> hl = convex_hull(a);
//    int N = hl.size();
//    vector<double> dl;
//    double len;
//    for(int v = 0; v < hl.size(); v++){
//        if(v == hl.size() - 1){
//            len = dist(hl[v], hl[0]);
//        }
//        else len = dist(hl[v], hl[v + 1]);
//        dl.push_back(len);
//    }
//    sort(dl.begin(), dl.end());
//    dl.resize(dl.size()-1);
//    double count = 0;
//    for(auto s: dl) {
//        count += s;
//    }
//    cout << count << endl;
}

signed main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);
//    double start = clock();
    int num_tests = 1;
#ifdef LOCAL
    std::cin >> num_tests;
#endif
    for (int i = 0; i < num_tests; ++i) {
#ifdef LOCAL
        std::cout << "Case #" << i + 1 << ":\n";
#endif
        Solve();
    }
#ifdef LOCAL
//    cout << "Time: " << (clock() - start) / CLOCKS_PER_SEC << "\n";
#endif
}