#include <iostream>
#include <unordered_map>
#include <vector>
#include <string>
#include <set>
#include <stack>
#include <queue>

typedef long long ll;

const size_t kSize = 1001;

char table[kSize][kSize];
ll used[kSize][kSize];
ll n, m;

bool valid(ll x, ll y) {
    return x > 0 && x <= n
            && y > 0 && y <= m;
}

void print() {
    std::cout << "\n";
    for(size_t i = 1; i <= n; ++i) {
        for (size_t j = 1; j <= m; ++j) {
            std::cout <<used[i][j] << " ";
        }
        std::cout << "\n";
    }
    std::cout << "\n";
}

ll ax, ay;
ll k;

void bfs(ll x, ll y) {
    used[x][y] = 0;

    auto neighbour = [](int x, int y, int i) {
        switch (i) {
            case 0:
                return std::pair{x - 1, y};
            case 1:
                return std::pair{x + 1, y};
            case 2:
                return std::pair{x, y - 1};
            case 3:
                return std::pair{x, y + 1};
        }
    };
    auto jump = [](int x, int y, int i) {
        switch (i) {
            case 0:
                return std::pair{x - 2, y};
            case 1:
                return std::pair{x + 2, y};
            case 2:
                return std::pair{x, y - 2};
            case 3:
                return std::pair{x, y + 2};
        }
    };
    std::pair<int, int> neig;
    std::pair<int, int> cur;
    std::pair<int, int> jumpy;
    ll nx, ny;
    std::queue<std::pair<int, int>> pq;
    pq.push({x, y});
    while (!pq.empty()) {
        cur = pq.front();
        if (used[cur.first][cur.second] > k) {
            continue;
        }
        pq.pop();
        for (size_t i = 0; i < 4; ++i) {
            neig = neighbour(cur.first, cur.second, i);
            if (valid(neig.first, neig.second)) {
                if (table[neig.first][neig.second] == '.'
                    && used[neig.first][neig.second] > used[cur.first][cur.second]) {
                    pq.push(neig);
                    used[neig.first][neig.second] = used[cur.first][cur.second];
                } else if (table[neig.first][neig.second] == '#') {
                    jumpy = jump(cur.first, cur.second, i);
                    if (valid(jumpy.first, jumpy.second)
                        && table[jumpy.first][jumpy.second] == '.'
                        && used[jumpy.first][jumpy.second] > used[cur.first][cur.second] + 1) {
                        pq.push(jumpy);
                        used[jumpy.first][jumpy.second] = used[cur.first][cur.second] + 1;
                    }
                }
            }
        }
        if (used[ax][ay] <= k) {
            return;
        }
    }
}

int main() {

    std::fill(table[0], table[0] + kSize * kSize, 0);
    std::fill(used[0], used[0] + kSize * kSize, LONG_LONG_MAX);
    char cell;
    std::cin >> n >> m >> k;
    for (size_t i = 1; i <= n; ++i) {
        for (size_t j = 1; j <= m; ++j) {
            std::cin >> cell;
            table[i][j] = cell;
        }
    }
    ll dx, dy;
    std::cin >> dx >> dy;
    std::cin >> ax >> ay;
    bfs(dx, dy);
    if(used[ax][ay] <= k) {
        std::cout << "YES";
    } else {
        std::cout << "NO";
    }

    return 0;
}