#include <deque>
#include <iostream>
#include <vector>
using namespace std;

#define INIT_FAST_IO                                                           \
  ios_base::sync_with_stdio(false);                                            \
  cin.tie(nullptr);

const int MAX_DIST = 1e7;

void processTest() {
  int numRows, numCols, maxSteps;
  cin >> numRows >> numCols >> maxSteps;

  vector<string> gameGrid(numRows + 1);
  for (int rowIdx = 1; rowIdx <= numRows; ++rowIdx) {
    cin >> gameGrid[rowIdx];
    gameGrid[rowIdx] = " " + gameGrid[rowIdx];
  }

  int startRow, startCol, targetRow, targetCol;
  cin >> startRow >> startCol >> targetRow >> targetCol;

  deque<pair<int, int>> nodesQueue;
  vector<vector<int>> distances(numRows + 1,
                                vector<int>(numCols + 1, MAX_DIST));

  distances[startRow][startCol] = 0;
  nodesQueue.push_front({startRow, startCol});

  vector<pair<int, int>> directMovements = {{1, 0}, {0, 1}, {-1, 0}, {0, -1}};
  vector<pair<int, int>> jumpMovements = {{2, 0}, {0, 2}, {-2, 0}, {0, -2}};

  while (!nodesQueue.empty()) {
    auto [currentRow, currentCol] = nodesQueue.front();
    nodesQueue.pop_front();

    for (auto &move : directMovements) {
      int newRow = currentRow + move.first;
      int newCol = currentCol + move.second;
      if (1 <= newRow && newRow <= numRows && 1 <= newCol &&
          newCol <= numCols && gameGrid[newRow][newCol] == '.' &&
          distances[newRow][newCol] > distances[currentRow][currentCol]) {

        distances[newRow][newCol] = distances[currentRow][currentCol];
        nodesQueue.push_front({newRow, newCol});
      }
    }

    for (auto &jump : jumpMovements) {
      int newRow = currentRow + jump.first;
      int newCol = currentCol + jump.second;
      if (1 <= newRow && newRow <= numRows && 1 <= newCol &&
          newCol <= numCols && gameGrid[newRow][newCol] == '.' &&
          distances[newRow][newCol] > distances[currentRow][currentCol] + 1) {

        distances[newRow][newCol] = distances[currentRow][currentCol] + 1;
        nodesQueue.push_back({newRow, newCol});
      }
    }
  }

  cout << (distances[targetRow][targetCol] <= maxSteps ? "YES\n" : "NO\n");
}

int main() {
  INIT_FAST_IO
  int testCases = 1;
  while (testCases--) {
    processTest();
  }
  return 0;
}
