#include <iostream>
#include <vector>
#include <deque>
#include <string>
using namespace std;

constexpr int MAX_DISTANCE = 1e7;

inline void setFastIO() {
  ios_base::sync_with_stdio(false);                                           
  cin.tie(nullptr);
}

struct Move {
    int x, y;
    Move(int a, int b) : x(a), y(b) {}
};

bool checkPosition(int x, int y, int r, int c, const vector<string>& grid) {
    return x >= 1 && x <= r && y >= 1 && y <= c && grid[x][y] == '.';
}

void solution() {
    int r, c, maxSteps;
    cin >> r >> c >> maxSteps;
    vector<string> grid(r + 1);

    for (int i = 1; i <= r; ++i) {
        cin >> grid[i];
        grid[i] = " " + grid[i];
    }

    int sx, sy, ex, ey;
    cin >> sx >> sy >> ex >> ey;

    vector<vector<int>> dist(r + 1, vector<int>(c + 1, MAX_DISTANCE));
    deque<pair<int, int>> dq;

    vector<Move> moves = {Move(1, 0), Move(0, 1), Move(-1, 0), Move(0, -1)};
    vector<Move> jumps = {Move(2, 0), Move(0, 2), Move(-2, 0), Move(0, -2)};

    dist[sx][sy] = 0;
    dq.emplace_front(sx, sy);

    while (!dq.empty()) {
        auto [cx, cy] = dq.front();
        dq.pop_front();

        for (auto& m : moves) {
            int nx = cx + m.x, ny = cy + m.y;
            if (checkPosition(nx, ny, r, c, grid) && dist[nx][ny] > dist[cx][cy]) {
                dist[nx][ny] = dist[cx][cy];
                dq.emplace_front(nx, ny);
            }
        }

        for (auto& j : jumps) {
            int nx = cx + j.x, ny = cy + j.y;
            if (checkPosition(nx, ny, r, c, grid) && dist[nx][ny] > dist[cx][cy] + 1) {
                dist[nx][ny] = dist[cx][cy] + 1;
                dq.emplace_back(nx, ny);
            }
        }
    }

    cout << (dist[ex][ey] <= maxSteps ? "YES\n" : "NO\n");
}

int main() {
    setFastIO();
    int tests = 1;
    if (tests){
      do
        {
          solution();
        }while(tests--);
    }
    return 0;
}
