#include <chrono>
#include <iostream>
#include <map>
#include <set>
#include <sstream>
#include <algorithm>
#include <stack>
#include <string>
#include <unordered_map>
#include <iomanip>
#include <vector>
#include <cmath>
#include <queue>

using namespace std;

int n, m, k;

int start_i, start_j, finish_i, finish_j;

const vector<pair<int, int>> moves{{1, 0}, {-1, 0}, {0, 1}, {0, -1}};
const vector<pair<int, int>> moves2{{2, 0}, {-2, 0}, {0, 2}, {0, -2}};


vector<vector<bool>> field;
vector<vector<int>> component;
vector<set<int>> graph;

int current_component = -1;

void dfs(int i, int j) {
    component[i][j] = current_component;
    for (auto [di, dj] : moves) {
        int next_i = i + di, next_j = j + dj;
        if (next_i >= 0 && next_i < n && next_j >= 0 && next_j < m) {
            if (field[next_i][next_j] && component[next_i][next_j] == -1) {
                dfs(next_i, next_j);
            }
        }
    }
}

const int INF = (int) 1e9;

vector<int> bfs() {
    vector<int> dist(current_component + 1, INF);
    dist[component[start_i][start_j]] = 0;
    queue<int> q;
    q.push(component[start_i][start_j]);
    while (!q.empty()) {
        int s = q.front();
        q.pop();
        for (int to : graph[s]) {
            if (dist[to] == INF) {
                dist[to] = dist[s] + 1;
                q.push(to);
            }
        }
    }
    return dist;
}

signed main() {
#ifdef LOCAL
    freopen("/Users/dmitrykutsenko/CLionProjects/cpp/input.txt", "r", stdin);
    freopen("/Users/dmitrykutsenko/CLionProjects/cpp/output.txt", "w", stdout);
#endif
    cin >> n >> m >> k;
    field.assign(n, vector<bool>(m));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            char c;
            cin >> c;
            field[i][j] = (c == '.');
        }
    }
    component.assign(n, vector<int>(m, -1));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (field[i][j] && component[i][j] == -1) {
                current_component++;
                dfs(i, j);
            }
        }
    }
    graph.resize(current_component + 1);
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (field[i][j]) {
                for (auto [di, dj] : moves2) {
                    int next_i = i + di, next_j = j + dj;
                    if (next_i >= 0 && next_i < n && next_j >= 0 && next_j < m) {
                        if (field[next_i][next_j] && component[next_i][next_j] != component[i][j]) {
                            graph[component[i][j]].insert(component[next_i][next_j]);
                            graph[component[next_i][next_j]].insert(component[i][j]);
                        }
                    }
                }
            }
        }
    }
    cin >> start_i >> start_j >> finish_i >> finish_j;
    start_i--, start_j--, finish_i--, finish_j--;
    vector<int> dist = bfs();
    cout << (dist[component[finish_i][finish_j]] <= k ? "YES" : "NO");
}

