#include <bits/stdc++.h>

typedef long long ll;
typedef long double ld;
using namespace std;

const ll INF = 1e18;

struct Vector {
    ll x, y;

    Vector (): x(0), y(0) {}
    Vector (ll x, ll y): x(x), y(y) {}

    ll length2() {
        return x*x + y*y;
    }

    ld length() {
        return sqrtl(length2());
    }

    Vector operator+(Vector other) {
        return Vector(x + other.x, y + other.y);
    }

    Vector operator-(Vector other) {
        return Vector(x - other.x, y - other.y);
    }

    ll operator*(Vector other) {
        return x*other.x + y*other.y;
    }

    ll operator^(Vector other) {
        return x*other.y - y*other.x;
    }
};

istream& operator>>(istream& is, Vector &vec) {
    return is >> vec.x >> vec.y;
}

ostream& operator<<(ostream& os, Vector vec) {
    os << vec.x << ' ' << vec.y;
    return os;
}

bool is_in_polygon(vector <Vector> &polygon, Vector point) {
    int mid, l = 1, r = polygon.size() - 1;
    while (r - l > 1) {
        mid = (l + r) / 2;

        if (((polygon[mid] - polygon[0]) ^ (point - polygon[0])) <= 0) {
            r = mid;
        } else {
            l = mid;
        }
    }

    if (((polygon[r] - polygon[0]) ^ (point - polygon[0])) <= 0 && ((polygon[r - 1] - polygon[r]) ^ (point - polygon[r])) <= 0) {
        return true;
    }   

    return false;
}

struct Line {
    ll A, B, C;

    Line (Vector a, Vector b) {
        A = a.y - b.y;
        B = b.x - a.x;
        C = a ^ b;
    }

    ld distance(Vector point) {
        return abs(point.x * A + point.y * B + C) / sqrtl(A*A + B*B);
    }
};

struct Segment {
    Vector a, b;

    Segment (Vector a, Vector b): a(a), b(b) {}

    ld distance(Vector point) {
        ld answer = min((a - point).length(), (b - point).length());
        if (((point - a) * (b - a)) >= 0 && ((point - b) * (a - b)) >= 0) {
            answer = min(answer, Line(a, b).distance(point));
        }

        return answer;
    }
};

int get_mid(int l, int r, int n) {
    if (l < r) {
        return (l + r) / 2;
    }

    return (r + (n - r + l) / 2) % n;
}

ld distance(vector <Vector> &polygon, Vector point) {
    // int n = (int)polygon.size();
    // int mid, l = 0, r = n - 1;
    // while (r - l > 1) {
    //     mid = (l + r) / 2;

    //     if (((polygon[mid] - polygon[l]) ^ (point - polygon[l])) <= 0) {
    //         r = mid;
    //     } else {
    //         l = mid;
    //     }
    // }

    // ld answer = INF;
    // for (int i = -3; i <= 3; i++) {
    //     int a = (l + i + n) % n;
    //     int b = (l + i + n + 1) % n;
    //     answer = min(answer, Segment(polygon[a], polygon[b]).distance(point));
    // }

    ld answer = INF;
    for (int i = 0; i < polygon.size(); i++) {
        Vector p1 = i ? polygon[i - 1] : polygon.back(), p2 = polygon[i];
        answer = min(answer, Segment(p1, p2).distance(point));
    }

    return answer;
}

ld ass(ld P, ld k) {
    return P * k + (ld)3.14159265358979323846 * k * k;
}

void get_ans(ld P, ld s0, vector <ld> &d, vector <int>& ans) {
    for (int i =0 ; i<  ans.size(); i++) {
        if (ans[i] != 0 ) {
            ans[i] = ceil(log2(ass(P, d[i]) / s0));
        }
    }
}

void solve() {
    int n;
    cin >> n;

    vector <Vector> polygon(n);
    for (auto &p: polygon)
        cin >> p;

    int m;
    cin >> m;

    ld s0 = 0, P = 0;
    for (int i = 0; i < polygon.size(); i++) {
        Vector p1 = i ? polygon[i - 1] : polygon.back(), p2 = polygon[i];
        s0 += (ld)(p1 ^ p2) / 2;
        P += (p2 - p1).length();
    }

    s0 = abs(s0);

    vector <Vector> points(m);
    for (auto &p: points) {
        cin >> p;
    }

    vector <ld> d(m);
    vector <int> ans(m, -1);
    for (int i = 0; i < m; i++) {
        if (is_in_polygon(polygon, points[i])) {
            ans[i] = 0;
        } else {
            d[i] = distance(polygon, points[i]);
        }

        // cout << "dist to " << i << " = " << d[i] << '\n';
    }
        
    // cerr << "S0 = " << s0 << ", P = " << P << '\n';
    get_ans(P, s0, d, ans);

    for (int x: ans)
        cout << x << '\n';
}

signed main() {
    cin.tie(NULL);
    ios_base::sync_with_stdio(false);

    solve();
}