#include <bits/stdc++.h>
using namespace std;
 
// #define int long long
#define double long double
#define ld double
 
#define all(x) x.begin(), x.end()
 
const int INF = 2e9 + 5;
const int SZ = 1 << 18;
const double eps = 1e-10;
const double pi = acos(-1);
 
struct Point {
    double x;
    double y;
    double angle() const {
        return atan2(y, x);
    }
    double len() const {
        return x*x + y*y;
    }
    Point () {}
    Point (double A, double B) : x(A), y(B) {}
};
 
double dist (const Point& p, const Point& q){
    double x = p.x - q.x;
    double y = p.y - q.y;
    return sqrtl(x*x + y*y);
}

// double dist (const Point& p, const Point& q){
//     return -1;
// }

double angl (const Point& p, const Point& q){
    double a = p.angle();
    double b = q.angle();
    if (a > b){
        swap(a, b);
    }
    return min(b - a, 2*pi + a - b);
}

double vect (const Point& p, const Point& q){
    return p.x*q.y - p.y*q.x;
}

istream& operator >> (istream& in, Point& p){
    in >> p.x >> p.y;
    return in;
}
 
ostream& operator << (ostream& out, const Point& p){
    out << p.x << ' ' << p.y;
    return out;
}
 
bool operator < (const Point& p, const Point& q){
    return p.x < q.x - eps || p.x < q.x + eps && p.y < q.y;
}
 
Point operator * (double k, const Point& p){
    return Point(p.x * k, p.y * k);
}

Point operator + (const Point& p, const Point& q){
    return {p.x + q.x, p.y + q.y};
}

Point operator - (const Point& p, const Point& q){
    return {p.x - q.x, p.y - q.y};
}
 
double scal(const Point& p, const Point& q){
    return p.x*q.x + p.y*q.y;
}
 
double dst_2(const Point& p, const Point& q){
    double x = p.x - q.x;
    double y = p.y - q.y;
    return x*x + y*y;
}
 
double area2(vector<Point>& a){
    Point p;
    Point last = a.back();
    double s = 0;
    for (auto cur : a){
        s += vect(cur - p, last - p);
        last = cur;
    }
    return abs(s);
}
 
struct Line{
    double a, b, c;
    Point v;
    Line (double A, double B, double C) : a(A), b(B), c(C) {
        double len = Point(a, b).len();
        a /= len; b /= len; c /= len;
 
        if (a < 0 || a == 0 && b < 0){
            a *= -1; b *= -1; c *= -1;
        }
 
        v = Point(-b, a);
    }
 
    Line (const Point& p, const Point& q){
        a = p.y - q.y;
        b = q.x - p.x;
        c = -(p.x*a + p.y*b);
        *this = Line(a, b, c);
    }
 
    double distance(const Point& p){
        return abs(a*p.x + b*p.y + c);
    }
};
 
ostream& operator << (ostream& out, const Line& l){
    out << l.a << ' ' << l.b << ' ' << l.c << endl;
    return out;
}
 
struct Beam {
    Line l;
    Point v;
    Point b;
    Beam (const Point& p, const Point& q) : b(p), v(q), l(p, q){}
 
    double distance(const Point& p){
        if (scal(v - b, p - b) < 0){
            return sqrt(dst_2(b, p));
        }
        return l.distance(p);
    }
};
 
struct Segment {
    Point p, q;
    Beam b1, b2;
    Segment (Point p, Point q) : p(min(p, q)), q(max(p, q)), b1(p, q), b2(q, p) {}
    
    double distance(const Point& p){
        return max(b1.distance(p), b2.distance(p));
    }
};
 
int n;
double P = 0;
double A = 0;
double S = 0;
Point a[SZ];

double dst[SZ];

int sz = 1;

void solve(){

    cin >> n;
    for (int i = 1; i <= n; i++){
        cin >> a[i];
    }
    a[0] = a[n];
    a[n + 1] = a[1];

    for (int i = 1; i <= n; i++){
        P += dist(a[i], a[i + 1]);
        A += pi - angl(a[i - 1] - a[i], a[i + 1] - a[i]);
        S += abs(vect(a[i + 1] - a[1], a[i] - a[1]));
    }

    A /= 2;

    dst[0] = 0;
    double cs = S;
    for (sz = 1; dst[sz - 1] < 1e12; sz++){
        double d = sqrtl(P*P + 4*A*cs);
        double x = (-P + d) / (2*A);
        dst[sz] = x;
        cs *= 2;
    }

    int q;
    cin >> q;
    while (q--){
        Point p;
        cin >> p;
        double mn = INF;
        double keks = 0;
        for (int i = 1; i <= n; i++){
            Segment s(a[i], a[i + 1]);
            mn = min(mn, s.distance(p));
            keks += abs(vect(a[i] - p, a[i + 1] - p));
        }
        mn *= 2;

        if (abs(keks - S) < eps){
            cout << "0\n";
            continue;
        }

        for (int i = 0; ; i++){
            if (dst[i] > mn - eps){
                cout << i << '\n';
                break;
            }
        }

    }

}
 
signed main(){
 
    // freopen("input.txt", "r", stdin);
 
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
 
    cout << fixed << setprecision(10);
 
    int t = 1;
    // cin >> t;
 
    while (t--){
        solve();
        cout << '\n';
    }
}