#include <iostream>
#include <vector>
#include <string>
#include <set>
#include <map>
#include <utility>
#include <stack>
#include <algorithm>
#include <cstdio>
#include <fstream>
#include <cmath>
#include <bitset>
#include <queue>
#include <assert.h>

using namespace std;

#define print(x) cout << x << endl
#define pb push_back
#define mp make_pair
#define ll long long
#define ld long double
#define INF INT64_MAX

#define int ll

int getpos(char c) {
    if (isdigit(c)) {
        return 52 + (c - '0');
    }
    if ('A' <= c && c <= 'Z') {
        return 26 + (c - 'A');
    }
    return c - 'a';
}

struct Node {
    bool terminal;
    int counter;

    vector<Node *> links;

    Node(bool term, int c) {
        terminal = term;
        counter = c;
        links.resize(62, nullptr);
    }
};

bool simple_find(Node *v, const string& s, int pos) {
    if (pos == s.size()) {
        return v->terminal;
    }

    int k = getpos(s[pos]);
    if (!v->links[k]) {
        return false;
    }
    return simple_find(v->links[k], s, pos + 1);
}

bool check_counter(Node *root, int counter) {
    const string str = to_string(counter);
    return simple_find(root, str, 0);
}

void add(Node *v, const string& s, size_t pos) {
    if (pos == s.size()) {
        v->terminal = true;
        return;
    }

    int k = getpos(s[pos]);
    if (!v->links[k]) {
        v->links[k] = new Node(false, 1);
    }
    add(v->links[k], s, pos + 1);
}

int find(Node *v, const string& s, size_t pos) {
    if (pos == s.size()) {
        if (v->terminal) {
            while (check_counter(v, v->counter)) { v->counter++; }
            return v->counter;
        } else {
            return -1;
        }
    }

    int k = getpos(s[pos]);
    if (!v->links[k]) {
        return -1;
    }
    return find(v->links[k], s, pos + 1);
}

Node *root = new Node(false, 0);

void incrementCounter(Node *v, const string& s, size_t pos) {
    if (pos == s.size()) {
        v->counter++;
        return;
    }

    if (v && v->terminal) {
        v->counter++;
    }

    int k = getpos(s[pos]);
    incrementCounter(v->links[k], s, pos + 1);
}

void test(string login) {
    int cnt = find(root, login, 0);
//        cout << "Counter: " << cnt << '\n';
    if (cnt == -1) {
        add(root, login, 0);
        print(login);
    } else {
//            incrementCounter(root, login, 0);
        int new_cnt = find(root, login, 0);
        string new_string = login + to_string(new_cnt);
        add(root, new_string, 0);
//            cout << "Login: " << login << ' ' << new_cnt << '\n';
        print(login + to_string(new_cnt));
    }
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    int n;
    cin >> n;
    for (int i = 0; i < n; i++) {
        string login;
        cin >> login;
        int cnt = find(root, login, 0);
//        cout << "Counter: " << cnt << '\n';
        if (cnt == -1) {
            add(root, login, 0);
            print(login);
        } else {
//            incrementCounter(root, login, 0);
            int new_cnt = find(root, login, 0);
            string new_string = login + to_string(new_cnt);
            add(root, new_string, 0);
//            cout << "Login: " << login << ' ' << new_cnt << '\n';
            print(login + to_string(new_cnt));
        }
    }
//    for (int i = 0; i < 100000; i++) {
//        test("a" + to_string(i));
//    }
    return 0;
}