#include "iostream"
#include "vector"
#include "algorithm"
#include "queue"

using namespace std;

void DFS_find_simple_components(vector<vector<int>> &graph, vector<vector<int>> &components, int n, int m, int y, int x,
                                int curcolor) {
    components[y][x] = curcolor;
    graph[y][x] = 0;

    if (y > 0 and graph[y - 1][x] == 1) {
        DFS_find_simple_components(graph, components, n, m, y - 1, x, curcolor);
    }
    if (x < m - 1 and graph[y][x + 1] == 1) {
        DFS_find_simple_components(graph, components, n, m, y, x + 1, curcolor);
    }
    if (y < n - 1 and graph[y + 1][x] == 1) {
        DFS_find_simple_components(graph, components, n, m, y + 1, x, curcolor);
    }
    if (x > 0 and graph[y][x - 1] == 1) {
        DFS_find_simple_components(graph, components, n, m, y, x - 1, curcolor);
    }
}

void DFS_find_comps_of_comps(vector<vector<int>> &components, vector<vector<int>> &colors, vector<vector<int>> &adj_ans,
                             int n, int m, int y, int x) {

    colors[y][x] = 1;

    if (y > 0 and components[y - 1][x] >= 0 and colors[y - 1][x] == 0) {
        DFS_find_comps_of_comps(components, colors, adj_ans, n, m, y - 1, x);
    } else if (y > 1 and components[y - 1][x] == -1 and components[y - 2][x] != -1) {
        if (find(adj_ans[components[y][x]].begin(), adj_ans[components[y][x]].end(), components[y - 2][x]) == adj_ans[components[y][x]].end()) {
            adj_ans[components[y][x]].push_back(components[y - 2][x]);
        }
    }

    if (x < m - 1 and components[y][x + 1] >= 0 and colors[y][x + 1] == 0) {
        DFS_find_comps_of_comps(components, colors, adj_ans, n, m, y, x + 1);
    } else if (x < m - 2 and components[y][x + 1] == -1 and components[y][x + 2] != -1) {
        if (find(adj_ans[components[y][x]].begin(), adj_ans[components[y][x]].end(), components[y][x + 2]) == adj_ans[components[y][x]].end()) {
            adj_ans[components[y][x]].push_back(components[y][x + 2]);
        }
    }

    if (y < n - 1 and components[y + 1][x] >= 0 and colors[y + 1][x] == 0) {
        DFS_find_comps_of_comps(components, colors, adj_ans, n, m, y + 1, x);
    } else if (y < n - 2 and components[y + 1][x] == -1 and components[y + 2][x] != -1) {
        if (find(adj_ans[components[y][x]].begin(), adj_ans[components[y][x]].end(), components[y + 2][x]) == adj_ans[components[y][x]].end()) {
            adj_ans[components[y][x]].push_back(components[y + 2][x]);
        }
    }

    if (x > 0 and components[y][x - 1] >= 0 and colors[y][x - 1] == 0) {
        DFS_find_comps_of_comps(components, colors, adj_ans, n, m, y, x - 1);
    } else if (x > 1 and components[y][x - 1] == -1 and components[y][x - 2] != -1) {
        if (find(adj_ans[components[y][x]].begin(), adj_ans[components[y][x]].end(), components[y][x - 2]) == adj_ans[components[y][x]].end()) {
            adj_ans[components[y][x]].push_back(components[y][x - 2]);
        }
    }
}

//find if the way from cur to dest exists
int BFS_find_shortest_way(vector<vector<int>> &graph, int v, int cur, int dest) {
    if (cur == dest) {
        return 0;
    }

    vector<int> colors(v, 0);
    vector<int> dists(v, 0);

    queue<int> q;
    q.push(cur);
    colors[cur] = 1;

    while (!q.empty()) {
        cur = q.front();
        q.pop();
        for (int i = 0; i < graph[cur].size(); i++) {
            if (colors[graph[cur][i]] == 0) {
                dists[graph[cur][i]] = dists[cur] + 1;
                q.push(graph[cur][i]);
                colors[graph[cur][i]] = 1;
            }
        }
    }

    int ans = dists[dest];

    if (ans == 0) {
        return -1;
    } else {
        return ans;
    }
};


int main() {
    int n, m, k;
    cin >> n;
    cin >> m;
    cin >> k;
    //create matrix
    vector<vector<int>> rooms;
    for (int i = 0; i < n; i++) {
        rooms.emplace_back();
        for (int j = 0; j < m; j++) {
            char tmp;
            cin >> tmp;
            if (tmp == 46) { //char number for . symbol
                rooms[i].push_back(1);
            } else {
                rooms[i].push_back(0);
            }
        }
    }

    int start_y, start_x;
    cin >> start_y >> start_x;

    int finish_y, finish_x;
    cin >> finish_y >> finish_x;


    // find simple connectivity components
    vector<vector<int>> simple_components(n, vector<int>(m, -1));
    int curcolor = 0;

    for (int i = 0; i < rooms.size(); i++) {
        for (int j = 0; j < rooms[i].size(); j++) {
            if (rooms[i][j] == 1 and simple_components[i][j] == -1) {
                DFS_find_simple_components(rooms, simple_components, n, m, i, j, curcolor);
                curcolor += 1;
            }
        }
    }

    //find connectivity components of start and finish point

    int start_comp = simple_components[start_y - 1][start_x - 1];
    int finish_comp = simple_components[finish_y - 1][finish_x - 1];


    //find connectivity components of connectivity components
    vector<vector<int>> adj_list_components(curcolor, vector<int>());

    for (int i = 0; i < simple_components.size(); i++) {
        for (int j = 0; j < simple_components[i].size(); j++) {
            if (simple_components[i][j] != -1) {
                vector<vector<int>> component_colors(n, vector<int>(m, 0));
                DFS_find_comps_of_comps(simple_components, component_colors, adj_list_components, n, m, i, j);
            }
        }
    }


//    for (auto &i: simple_components) {
//        for (auto j: i) {
//            cout << j << " ";
//        }
//        cout << "\n";
//    }
//
//    cout << "\n";
//
//    for (auto &i: adj_list_components) {
//        for (auto j: i) {
//            cout << j << " ";
//        }
//        cout << "\n";
//    }

    //find the shortest jumping way

    int ans = BFS_find_shortest_way(adj_list_components, adj_list_components.size(), start_comp, finish_comp);

    if (ans > k or ans == -1) {
        cout << "NO";
    } else {
        cout << "YES";
    }

}